desordre
========

.. automodule:: abjad.demos.desordre

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.demos.desordre.make_desordre_cell.make_desordre_cell
      ~abjad.demos.desordre.make_desordre_lilypond_file.make_desordre_lilypond_file
      ~abjad.demos.desordre.make_desordre_measure.make_desordre_measure
      ~abjad.demos.desordre.make_desordre_pitches.make_desordre_pitches
      ~abjad.demos.desordre.make_desordre_score.make_desordre_score
      ~abjad.demos.desordre.make_desordre_staff.make_desordre_staff
